==> openshift-model-operator-5.10.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ForwardPluginFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ForwardPluginFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.ForwardPluginFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.ForwardPluginFluent<A>{
  public ForwardPluginFluentImpl() {
  }
  public ForwardPluginFluentImpl(io.fabric8.openshift.api.model.operator.v1.ForwardPlugin instance) {
    this.withUpstreams(instance.getUpstreams()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> upstreams = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToUpstreams(java.lang.Integer index,java.lang.String item) {
    if (this.upstreams == null) {this.upstreams = new java.util.ArrayList<java.lang.String>();}
    this.upstreams.add(index, item);
    return (A)this;
  }
  public A setToUpstreams(java.lang.Integer index,java.lang.String item) {
    if (this.upstreams == null) {this.upstreams = new java.util.ArrayList<java.lang.String>();}
    this.upstreams.set(index, item); return (A)this;
  }
  public A addToUpstreams(java.lang.String... items) {
    if (this.upstreams == null) {this.upstreams = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.upstreams.add(item);} return (A)this;
  }
  public A addAllToUpstreams(java.util.Collection<java.lang.String> items) {
    if (this.upstreams == null) {this.upstreams = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.upstreams.add(item);} return (A)this;
  }
  public A removeFromUpstreams(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.upstreams!= null){ this.upstreams.remove(item);}} return (A)this;
  }
  public A removeAllFromUpstreams(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.upstreams!= null){ this.upstreams.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getUpstreams() {
    return this.upstreams;
  }
  public java.lang.String getUpstream(java.lang.Integer index) {
    return this.upstreams.get(index);
  }
  public java.lang.String getFirstUpstream() {
    return this.upstreams.get(0);
  }
  public java.lang.String getLastUpstream() {
    return this.upstreams.get(upstreams.size() - 1);
  }
  public java.lang.String getMatchingUpstream(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: upstreams) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingUpstream(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: upstreams) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withUpstreams(java.util.List<java.lang.String> upstreams) {
    if (upstreams != null) {this.upstreams = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : upstreams){this.addToUpstreams(item);}} else { this.upstreams = null;} return (A) this;
  }
  public A withUpstreams(java.lang.String... upstreams) {
    if (this.upstreams != null) {this.upstreams.clear();}
    if (upstreams != null) {for (java.lang.String item :upstreams){ this.addToUpstreams(item);}} return (A) this;
  }
  public java.lang.Boolean hasUpstreams() {
    return upstreams != null && !upstreams.isEmpty();
  }
  public A addNewUpstream(java.lang.String arg0) {
    return (A)addToUpstreams(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ForwardPluginFluentImpl that = (ForwardPluginFluentImpl) o;
    if (upstreams != null ? !upstreams.equals(that.upstreams) :that.upstreams != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(upstreams,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ForwardPluginFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ForwardPluginFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.ForwardPluginFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.ForwardPluginFluent<A>{
  public ForwardPluginFluentImpl() {
  }
  public ForwardPluginFluentImpl(io.fabric8.openshift.api.model.operator.v1.ForwardPlugin instance) {
    this.withPolicy(instance.getPolicy()); 
    this.withUpstreams(instance.getUpstreams()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String policy;
  private java.util.List<java.lang.String> upstreams = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getPolicy() {
    return this.policy;
  }
  public A withPolicy(java.lang.String policy) {
    this.policy=policy; return (A) this;
  }
  public java.lang.Boolean hasPolicy() {
    return this.policy != null;
  }
  
  /**
   * Method is deprecated. use withPolicy instead.
   */
  @java.lang.Deprecated
  public A withNewPolicy(java.lang.String arg0) {
    return (A)withPolicy(new String(arg0));
  }
  public A addToUpstreams(java.lang.Integer index,java.lang.String item) {
    if (this.upstreams == null) {this.upstreams = new java.util.ArrayList<java.lang.String>();}
    this.upstreams.add(index, item);
    return (A)this;
  }
  public A setToUpstreams(java.lang.Integer index,java.lang.String item) {
    if (this.upstreams == null) {this.upstreams = new java.util.ArrayList<java.lang.String>();}
    this.upstreams.set(index, item); return (A)this;
  }
  public A addToUpstreams(java.lang.String... items) {
    if (this.upstreams == null) {this.upstreams = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.upstreams.add(item);} return (A)this;
  }
  public A addAllToUpstreams(java.util.Collection<java.lang.String> items) {
    if (this.upstreams == null) {this.upstreams = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.upstreams.add(item);} return (A)this;
  }
  public A removeFromUpstreams(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.upstreams!= null){ this.upstreams.remove(item);}} return (A)this;
  }
  public A removeAllFromUpstreams(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.upstreams!= null){ this.upstreams.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getUpstreams() {
    return this.upstreams;
  }
  public java.lang.String getUpstream(java.lang.Integer index) {
    return this.upstreams.get(index);
  }
  public java.lang.String getFirstUpstream() {
    return this.upstreams.get(0);
  }
  public java.lang.String getLastUpstream() {
    return this.upstreams.get(upstreams.size() - 1);
  }
  public java.lang.String getMatchingUpstream(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: upstreams) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingUpstream(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: upstreams) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withUpstreams(java.util.List<java.lang.String> upstreams) {
    if (upstreams != null) {this.upstreams = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : upstreams){this.addToUpstreams(item);}} else { this.upstreams = null;} return (A) this;
  }
  public A withUpstreams(java.lang.String... upstreams) {
    if (this.upstreams != null) {this.upstreams.clear();}
    if (upstreams != null) {for (java.lang.String item :upstreams){ this.addToUpstreams(item);}} return (A) this;
  }
  public java.lang.Boolean hasUpstreams() {
    return upstreams != null && !upstreams.isEmpty();
  }
  public A addNewUpstream(java.lang.String arg0) {
    return (A)addToUpstreams(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ForwardPluginFluentImpl that = (ForwardPluginFluentImpl) o;
    if (policy != null ? !policy.equals(that.policy) :that.policy != null) return false;
    if (upstreams != null ? !upstreams.equals(that.upstreams) :that.upstreams != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(policy,  upstreams,  additionalProperties,  super.hashCode());
  }
  
}
